import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import QtMultimedia 5.0

MainView {
    id: mainView

    property bool flashlightStatus: false

    objectName: "mainView"
    applicationName: "flashlight-app"
    
    automaticOrientation: false
    width: units.gu(40)
    height: units.gu(71)

    Component.onCompleted: {
        Theme.name = "Ubuntu.Components.Themes.SuruGradient"

        camera.start()
    }

    Rectangle {
        id: backgroundRectangle
        anchors.fill: parent
        color: "#FFFFFF"
        visible: flashlightStatus
    }

    Page {
        id: flashlight
        title: i18n.tr("Flashlight")

        Item {
            id: header

            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.topMargin: units.gu(2)

            height: units.gu(12)
            width: parent.width

            Button {
                id: screen
                objectName: "screenButton"
                anchors.horizontalCenter: parent.horizontalCenter
                color: "#464646"
                height: units.gu(6)
                width: units.gu(20)

                ListItem.ItemSelector {
                    model: [i18n.tr("LED"), i18n.tr("Screen Light")]
                }
            }
        }

        Item {
            anchors.fill: parent

            Button {
                objectName: "enableButton"
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                height: units.gu(10)
                width: units.gu(10)
                text: flashlightStatus ? i18n.tr("Turn off") : i18n.tr("Turn on")

                onClicked: {
                    flashlightStatus = !flashlightStatus
                }
            }
        }
    }

    Camera {
        id: camera
        flash.mode: (flashlightStatus) ? Camera.FlashTorch : Camera.FlashOff
    }
}
